<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:java="http://xml.apache.org/xslt/java" xmlns:xalan="http://xml.apache.org/xalan" xmlns:dk="kelis.fr:dokiel" exclude-result-prefixes="sc sp dk java xalan">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="yes"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	<xsl:variable name="vId" select="alphaHash(getIdNode(..))"/>
	<xsl:variable name="vFileProps" select="parseXml(getProps(gotoSubModel(sp:img),'nav'))/props/file"/>
	<xsl:variable name="vImgProps" select="parseXml(getProps(gotoSubModel(sp:img),'nav'))/props/image"/>
	<xsl:variable name="vRatio" select="$vImgProps/@transformedWidth div $vImgProps/@nativeWidth"/>
	<xsl:variable name="vImgBox" select="concat('0,0,',$vImgProps/@nativeWidth,',',$vImgProps/@nativeHeight)"/>
	<xsl:template match="*" xmlns:scmath="xalan://eu.scenari.modeling.util.Math" xmlns:scimutil="xalan://eu.scenari.transform.img.ImageMagickUtil">
		<div class="screenFra">
			<div class="screenImg">
				<xsl:variable name="vTransformZones">
					<xsl:value-of select="concat('&amp;', scimutil:getTransformPrefix($vFileProps/@outType))"/>
					<xsl:variable name="vFillColor" select="genProp('dokiel.screen.zone.fillColor', '#FFF3')"/>
					<xsl:variable name="vStrokeColor" select="genProp('dokiel.screen.zone.strokeColor', 'gray')"/>
					<xsl:variable name="vStrokeWidth" select="genProp('dokiel.screen.zone.strokeWidth', '1')"/>
					<xsl:variable name="vStrokeType" select="genProp('dokiel.screen.zone.strokeType', 'dashed')"/>
					<xsl:variable name="vLabelColor" select="genProp('dokiel.screen.zone.labelColor', '#000A')"/>
					<xsl:variable name="vFontColor" select="genProp('dokiel.screen.zone.fontColor', 'white')"/>
					<xsl:variable name="vFontSize" select="genProp('dokiel.screen.zone.fontSize', '10')"/>
					<xsl:variable name="vImageDensity" select="$vImgProps/@transformedWidth div $vImgProps/@cmWidth * 2.54"/>
					<xsl:for-each select="sp:zone">
						<xsl:variable name="vShape" select="dk:screenZoneMeta/sp:geo/sp:shape/text()"/>
						<xsl:variable name="vCoords" select="scmath:coordsRatio(scmath:coordsCrop(dk:screenZoneMeta/sp:geo/sp:coords/text(),$vImgBox),$vRatio)"/>
						<xsl:value-of select="scimutil:getDrawShapeFragment($vShape,scmath:coordsRound($vCoords), $vFillColor, $vStrokeColor, $vStrokeWidth, $vStrokeType, $vImageDensity)"/>
					</xsl:for-each>
					<xsl:for-each select="sp:zone">
						<xsl:variable name="vShape" select="dk:screenZoneMeta/sp:geo/sp:shape/text()"/>
						<xsl:variable name="vCoords" select="scmath:coordsRatio(scmath:coordsCrop(dk:screenZoneMeta/sp:geo/sp:coords/text(),$vImgBox),$vRatio)"/>
						<xsl:variable name="vLabelText">
							<xsl:number format="1"/>
						</xsl:variable>
						<xsl:value-of select="scimutil:getDrawLabelFragment($vLabelText,scmath:coordsRound(scmath:coordsTopLeft($vCoords)), $vLabelColor, $vFontColor, $vFontSize, $vImageDensity)"/>
					</xsl:for-each>
					<xsl:value-of select="'%20%24dst'"/>
				</xsl:variable>
				<img src="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', $vFileProps/@transform, $vTransformZones))}" alt="">
					<xsl:attribute name="style">width:<xsl:value-of select="$vImgProps/@cmWidth"/>cm;height:<xsl:value-of select="$vImgProps/@cmHeight"/>cm;</xsl:attribute>
				</img>
			</div>
			<ul class="screenZones">
				<xsl:for-each select="sp:zone">
					<xsl:variable name="vCoords" select="scmath:coordsCrop(dk:screenZoneMeta/sp:geo/sp:coords/text(),$vImgBox)"/>
					<xsl:variable name="vZneCmDims" select="xalan:tokenize(computeStrAgent('//', concat('get:src:', $vFileProps/@source, '?', scimutil:getCropTransform($vFileProps/@outType, $vCoords), '&amp;', $vFileProps/@dimTransform, &quot;outRules=Str(pattern'!wcm_!hcm')&quot;)), '_')"/>
					<xsl:variable name="vLeft" select="max(number(returnFirst(substring-before($vCoords,','),0)), 0)"/>
					<xsl:variable name="vTop" select="max(number(returnFirst(substring-before(substring-after($vCoords,','),','),0)), 0)"/>
					<xsl:variable name="vWidth" select="$vZneCmDims[1]"/>
					<xsl:variable name="vHeight" select="$vZneCmDims[2]"/>
					<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
					<xsl:variable name="vZneTi" select="dk:screenZoneMeta/sp:title"/>
					<xsl:variable name="vZneIsTall" select="$vWidth &lt; number(genProp('dokiel.screen.zone.tall.maxWidth', '6')) and $vHeight &gt; number(genProp('dokiel.screen.zone.tall.minHeight', '3'))"/>
					<li class="screenZone {if($vZneIsTall,'screenZone_tall','screenZone_wide')}">
						<div class="screenZone_ti">
							<span class="zoneNumber">
								<xsl:value-of select="$vZneNum"/>
							</span>
							<span>
								<xsl:value-of select="if($vZneTi, concat(' ',$vZneTi))"/>
							</span>
						</div>
						<div class="screenZone_co" style="min-height:{$vHeight}cm;">
							<xsl:choose>
								<xsl:when test="$vZneIsTall">
									<table class="screenZone_tb">
										<tr>
											<td class="screenZone_pre">
												<xsl:attribute name="style">width:<xsl:value-of select="$vWidth"/>cm;</xsl:attribute>
												<img src="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', scimutil:getCropTransform($vFileProps/@outType, $vCoords), '&amp;', $vFileProps/@transform ))}" class="" alt="{dk:screenZoneMeta/sp:title}">
													<xsl:attribute name="style">width:<xsl:value-of select="$vWidth"/>cm;height:<xsl:value-of select="$vHeight"/>cm;</xsl:attribute>
												</img>
											</td>
											<td class="screenZone_desc">
												<xsl:value-of select="getContent(gotoSubModel(.),'scrZTall')" disable-output-escaping="yes"/>
											</td>
										</tr>
									</table>
								</xsl:when>
								<xsl:otherwise>
									<div class="screenZone_pre">
										<img src="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', scimutil:getCropTransform($vFileProps/@outType, $vCoords), '&amp;', $vFileProps/@transform ))}" class="" alt="{dk:screenZoneMeta/sp:title}">
											<xsl:attribute name="style">width:<xsl:value-of select="$vWidth"/>cm;height:<xsl:value-of select="$vHeight"/>cm;</xsl:attribute>
										</img>
									</div>
									<div class="screenZone_desc">
										<xsl:value-of select="getContent(gotoSubModel(.),'')" disable-output-escaping="yes"/>
									</div>
								</xsl:otherwise>
							</xsl:choose>
						</div>
						<div class="screenZone_end" style="clear:left;"/>
					</li>
				</xsl:for-each>
			</ul>
		</div>
	</xsl:template>
</xsl:stylesheet>
