<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
		xmlns:sfm="http://www.utc.fr/ics/scenari/v3/filemeta"
		xmlns:dk="kelis.fr:dokiel"
		xmlns:pw="scpf.org:presWsp"
		xmlns:xalan="http://xml.apache.org/xalan"
		exclude-result-prefixes="sc sp xalan pw">
	<xsl:output encoding="UTF-8" method="xml"/>

	<!--<xsl:template match="/*">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>-->
	
	<xsl:template match="dk:flowAll">
		<xsl:if test="sp:txtRes/dk:txtRes/sp:txt/dk:text/sc:table">
			<xsl:comment>Le texte du texte illustré contenait un tableau, ceci n’est plus possible dans Dokiel</xsl:comment>
		</xsl:if>
		<dk:flowAll>
			<sp:txt>
				<dk:text>
					<xsl:for-each select="sp:txt/dk:text/* | sp:fig | sp:txtRes | sp:seeAlso">
						<xsl:variable name="vName"><xsl:value-of select="local-name(.)"/></xsl:variable>
						<xsl:choose>
							<xsl:when test="$vName='seeAlso'" >
								<xsl:apply-templates select="." mode="inText"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
<!--					<xsl:apply-templates select="sp:txt/dk:text/* | sp:fig | sp:txtRes | sp:seeAlso" />-->
				</dk:text>
			</sp:txt>
		</dk:flowAll>
	</xsl:template>
	
	<xsl:template match="sp:fig | sp:imgBk">
		<sc:extBlock role="fig" sc:refUri="{@sc:refUri}" />
	</xsl:template>
	
	
	<xsl:template match="sp:txtRes">
		<sc:table role="simpleTable">
			<sc:column  width="50"/>
			<sc:column width="50"/>
			<sc:row>
				<xsl:choose>
					<xsl:when test="dk:txtRes/dk:txtResM/sp:pos='lft'">
						<sc:cell >
							<xsl:apply-templates select=".//sp:imgBk"/>
						</sc:cell>
						<sc:cell >
							<xsl:apply-templates select=".//sp:txt/dk:text/*"/>
						</sc:cell>
					</xsl:when>
					<xsl:otherwise>
						<sc:cell >
							<xsl:apply-templates select=".//sp:txt/dk:text/*"/>
						</sc:cell>
						<sc:cell >
							<xsl:apply-templates select=".//sp:imgBk"/>
						</sc:cell>
					</xsl:otherwise>
				</xsl:choose>
			</sc:row>
		</sc:table>
	</xsl:template>
	
	<xsl:template match="sp:seeAlso" mode="inText">
		<xsl:apply-templates select="dk:linkSection" mode="inText"/>
	</xsl:template>
	
	
	<xsl:template match="dk:linkSection" mode="inText">
		<xsl:choose>
			<xsl:when test="dk:sTitle/sc:fullTitle">
				<sc:para xml:space="preserve"><sc:inlineStyle role="emphasis"><xsl:apply-templates select="dk:sTitle/sc:fullTitle/node()" /></sc:inlineStyle>
				</sc:para>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates select="sp:ref | sp:doc" mode="inText" />
	</xsl:template>
	
	<xsl:template match="sp:ref" mode="inText" >
		<xsl:variable name="vDocument" select="try(parseXml(resolveSrcPath(@sc:refUri, $pCurrentItem)), 'Warning', concat('Item ', @sc:refUri, ' est en erreur.'))"/>
		<xsl:variable name="vTitle"><xsl:copy-of select="$vDocument/sc:item/dk:section/dk:title/sc:fullTitle"/></xsl:variable>
		<xsl:variable name="vsTitle"><xsl:copy-of select="$vDocument/sc:item/dk:section/dk:title/sc:shortTitle"/></xsl:variable>
		<!-- cas où la section liée a déjà été migrée (contournement, sinon : faire deux scripts de migration) -->
		<xsl:variable name="vMigrTitle"><xsl:copy-of select="$vDocument/sc:item/dk:section/dk:headTitle/sp:sTitle"/></xsl:variable>
		<sc:para >
			<sc:uLink role="coLnk" sc:refUri="{@sc:refUri}">
				<xsl:choose>
					<xsl:when test="$vTitle"><xsl:value-of select="$vTitle"/></xsl:when>				
					<xsl:when test="$vsTitle"><xsl:value-of select="$vsTitle"/></xsl:when>				
					<xsl:when test="$vMigrTitle"><xsl:value-of select="$vMigrTitle"/></xsl:when>
					<xsl:otherwise>SEC</xsl:otherwise>
				</xsl:choose>
			</sc:uLink>
		</sc:para>
	</xsl:template>
	
	<xsl:template match="sp:doc" mode="inText" >
	
		<xsl:variable name="vDocument" select="try(parseXml(resolveSrcPath('meta.xml', resolveSrcPath(@sc:refUri, $pCurrentItem))), 'Warning', concat('Item ', @sc:refUri, ' est en erreur.'))"/>
		<xsl:variable name="vTitle"><xsl:copy-of select="$vDocument/sfm:pdf/dk:docMeta/sp:title"/></xsl:variable>
		<!-- cas où le pdf lié a déjà été migré  (contournement, sinon : faire deux scripts de migration) -->
		<xsl:variable name="vMigrTitle"><xsl:copy-of select="$vDocument/sfm:pdf/dk:mediaM/sp:title/dk:rTitle/sp:rTitle/dk:richTitle/sc:para"/></xsl:variable>
		<sc:para >
			<sc:uLink role="resLnk" sc:refUri="{@sc:refUri}">
				<xsl:choose>
					<xsl:when test="dk:sTitle/sc:fullTitle">
						<xsl:apply-templates select="dk:sTitle/sc:fullTitle/node()" />
					</xsl:when>
					<xsl:when test="$vTitle"><xsl:value-of select="$vTitle"/></xsl:when>
					<xsl:when test="$vMigrTitle"><xsl:value-of select="$vMigrTitle"/></xsl:when>
					<xsl:otherwise>PDF</xsl:otherwise>
				</xsl:choose>
			</sc:uLink>
		</sc:para>
	</xsl:template>

	
	<!-- ### 
		# Cas général : on copie
		### -->
<!--	<xsl:template match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template> -->
		
</xsl:stylesheet>