<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:java="http://xml.apache.org/xslt/java" xmlns:xalan="http://xml.apache.org/xalan" xmlns:dk="kelis.fr:dokiel" exclude-result-prefixes="sc sp dk xalan">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="yes"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	<xsl:variable name="vId" select="alphaHash(getIdNode(..))"/>
	<xsl:variable name="vFileProps" select="parseXml(getProps(gotoSubModel(sp:img),'nav'))/props/file"/>
	<xsl:variable name="vImgProps" select="parseXml(getProps(gotoSubModel(sp:img),'nav'))/props/image"/>
	<xsl:variable name="vImgUri" select="getUrl(gotoSubModel(sp:img),'nav')"/>
	<xsl:variable name="vImgHeight" select="number($vImgProps/@transformedHeight)"/>
	<xsl:variable name="vRatio" select="$vImgProps/@transformedWidth div $vImgProps/@nativeWidth"/>
	<xsl:variable name="vHasZoneTitles" select="boolean(//dk:screenZoneMeta/sp:title/text())"/>
	<xsl:template match="*" xmlns:scmath="xalan://eu.scenari.modeling.util.Math" xmlns:scimutil="xalan://eu.scenari.transform.img.ImageMagickUtil">
		<xsl:if test="sp:desc">
			<div class="screenDesc">
				<xsl:value-of select="getContent(gotoSubModel(sp:desc),'')" disable-output-escaping="yes"/>
			</div>
		</xsl:if>
		<div class="screenFra">
			<xsl:variable name="vImgId" select="concat($vId,generate-id(sp:img))"/>
			<div class="caption">
				<div id="{$vImgId}" class="screenImgFra">
					<table role="presentation">
						<tr>
							<td>
								<div class="screenImg" style="position:relative;height:{$vImgProps/@transformedHeight}px;width:{$vImgProps/@transformedWidth}px;">
									<img src="{$vImgUri}" width="{$vImgProps/@transformedWidth}" height="{$vImgProps/@transformedHeight}" class="" alt="{getFullTitleText(gotoSubModel(sp:img),'')}"/>
									<div class="screenMask" style="position:absolute;height:{$vImgProps/@transformedHeight}px;width:{$vImgProps/@transformedWidth}px;top:0;left:0;"/>
									<xsl:for-each select="sp:zone">
										<xsl:variable name="vCoords" select="scmath:coordsRound(scmath:coordsRatio(dk:screenZoneMeta/sp:geo/sp:coords/text(),$vRatio))"/>
										<xsl:variable name="vLeft" select="max(number(returnFirst(substring-before($vCoords,','),0)), 0)"/>
										<xsl:variable name="vTop" select="max(number(returnFirst(substring-before(substring-after($vCoords,','),','),0)), 0)"/>
										<xsl:variable name="vWidth" select="number(returnFirst(min(substring-before(substring-after(substring-after($vCoords,','),','),','),$vImgProps/@transformedWidth) - $vLeft,0))"/>
										<xsl:variable name="vHeight" select="number(returnFirst(min(substring-after(substring-after(substring-after($vCoords,','),','),','),$vImgProps/@transformedHeight) - $vTop,0))"/>
										<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
										<a class="screenZoneLnk" href="#{concat($vId,generate-id(.))}" style="position:absolute;top:{round($vTop)}px;left:{round($vLeft)}px;width:{round($vWidth)}px;height:{round($vHeight)}px;">
											<xsl:if test="dk:screenZoneMeta/sp:title">
												<addAttribute name="title" filter="textOnly">
													<xsl:value-of select="$vZneNum"/> - <xsl:value-of select="dk:screenZoneMeta/sp:title"/>
												</addAttribute>
											</xsl:if>
											<span class="zoneNumber">
												<xsl:value-of select="$vZneNum"/>
											</span>
											<span class="zoneArea"/>
										</a>
									</xsl:for-each>
								</div>
							</td>
							<xsl:if test="$vHasZoneTitles and ($vImgHeight&gt;150 or count(sp:zone)*30&lt;=$vImgHeight)">
								<td>
									<div class="screenTitles" style="position:relative;height:{$vImgProps/@transformedHeight}px;overflow-y:auto;">
										<ul>
											<xsl:for-each select="sp:zone">
												<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
												<xsl:variable name="vZneTi" select="dk:screenZoneMeta/sp:title"/>
												<li>
													<a class="screenTitleLnk" href="#{concat($vId,generate-id(.))}">
														<span class="zoneNumber">
															<xsl:value-of select="$vZneNum"/>
														</span>
														<span>
															<xsl:value-of select="if($vZneTi, concat(' ',$vZneTi), ' ...')"/>
														</span>
													</a>
												</li>
											</xsl:for-each>
										</ul>
									</div>
								</td>
							</xsl:if>
						</tr>
					</table>
				</div>
			</div>
			<ul class="screenZones">
				<xsl:for-each select="sp:zone">
					<xsl:variable name="vCoords" select="scmath:coordsRound(scmath:coordsRatio(dk:screenZoneMeta/sp:geo/sp:coords/text(),$vRatio))"/>
					<xsl:variable name="vLeft" select="max(number(returnFirst(substring-before($vCoords,','),0)), 0)"/>
					<xsl:variable name="vTop" select="max(number(returnFirst(substring-before(substring-after($vCoords,','),','),0)), 0)"/>
					<xsl:variable name="vWidth" select="number(returnFirst(min(substring-before(substring-after(substring-after($vCoords,','),','),','),$vImgProps/@transformedWidth) - $vLeft,0))"/>
					<xsl:variable name="vHeight" select="number(returnFirst(min(substring-after(substring-after(substring-after($vCoords,','),','),','),$vImgProps/@transformedHeight) - $vTop,0))"/>
					<xsl:variable name="vZneRatio" select="$vWidth div $vHeight"/>
					<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
					<xsl:variable name="vZneTi" select="dk:screenZoneMeta/sp:title"/>
					<xsl:variable name="vZneIsTallRatio" select="number(genProp('dokiel.screen.zone.tallRatio', '4'))"/>
					<xsl:variable name="vZneIsTallMaxWidth" select="number(genProp('dokiel.screen.zone.tallMaxWidth', '500'))"/>
					<xsl:variable name="vZneIsZoomRatio" select="number(genProp('dokiel.screen.zone.zoomRatio', '0.9'))"/>
					<xsl:variable name="vZneIsTall" select="$vZneRatio&lt;$vZneIsTallRatio and $vWidth&lt;=$vZneIsTallMaxWidth"/>
					<li class="screenZone {if($vZneIsTall,'screenZone_tall','screenZone_wide')}" id="{concat($vId,generate-id(.))}">
						<div class="screenZone_ti">
							<span class="zoneNumber">
								<xsl:value-of select="$vZneNum"/>
							</span>
							<span>
								<xsl:value-of select="if($vZneTi, concat(' ',$vZneTi))"/>
							</span>
						</div>
						<div class="screenZone_co" style="min-height:{$vHeight}px;">
							<div class="screenZone_pre">
								<xsl:if test="$vZneIsTall">
									<xsl:attribute name="style">float:left;</xsl:attribute>
								</xsl:if>
								<xsl:choose>
									<xsl:when test="$vRatio&lt;$vZneIsZoomRatio">
										<a href="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', scimutil:getCropTransform($vFileProps/@outType, dk:screenZoneMeta/sp:geo/sp:coords/text())))}" class="zoneZoom">
											<img src="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', $vFileProps/@transform, '&amp;', scimutil:getCropTransform($vFileProps/@outType, $vCoords)))}" width="{$vWidth}" height="{$vHeight}" class="" alt="{dk:screenZoneMeta/sp:title}"/>
										</a>
									</xsl:when>
									<xsl:otherwise>
										<img src="{computeStrAgent('//', concat('res:src=src:', $vFileProps/@source, ';', $vFileProps/@transform, '&amp;', scimutil:getCropTransform($vFileProps/@outType, $vCoords)))}" width="{$vWidth}" height="{$vHeight}" class="" alt="{dk:screenZoneMeta/sp:title}"/>
									</xsl:otherwise>
								</xsl:choose>
							</div>
							<div class="screenZone_desc">
								<xsl:if test="$vZneIsTall">
									<xsl:attribute name="style">margin-left:<xsl:value-of select="$vWidth"/>px;</xsl:attribute>
								</xsl:if>
								<xsl:value-of select="getContent(gotoSubModel(.),'')" disable-output-escaping="yes"/>
							</div>
						</div>
						<div class="screenZone_end" style="clear:left;">
							<xsl:if test="count(preceding-sibling::sp:zone)&gt;4">
								<a href="#{$vImgId}" title="Retourner à l&apos;écran">
									<span>Retourner à l&apos;écran</span>
								</a>
							</xsl:if>
						</div>
					</li>
				</xsl:for-each>
			</ul>
		</div>
	</xsl:template>
</xsl:stylesheet>